pub struct PlayerTextures {
pub skin: Url,
pub cape: Option<Url>,
}Expand description
Contains URLs to the skin and cape of a player.
Fields
skin: UrlURL to the player’s skin texture.
cape: Option<Url>URL to the player’s cape texture. May be absent if the player does not have a cape.
Implementations
Sourceimpl PlayerTextures
impl PlayerTextures
Sourcepub fn try_from_textures(textures: &str) -> Result<Self>
pub fn try_from_textures(textures: &str) -> Result<Self>
Constructs player textures from the “textures” property of the game profile.
“textures” is a base64 string of JSON data.